@@ -892,6 +892,7 @@ CMD_allterms,
 CMD_and,
 CMD_cgi,
 CMD_cgilist,
+CMD_cgiparams,
 CMD_chr,
 CMD_collapsed,
 CMD_contains,
@@ -1021,6 +1022,7 @@ T(allterms,	   0, 1, N, 0), // list of all terms matching document
 T(and,		   1, N, 0, 0), // logical shortcutting and of a list of values
 T(cgi,		   1, 1, N, 0), // return cgi parameter value
 T(cgilist,	   1, 1, N, 0), // return list of values for cgi parameter
+T(cgiparams,	   0, 0, N, 0), // return list of cgi parameter names
 T(chr,		   1, 1, N, 0), // return UTF-8 for given Unicode codepoint
 T(collapsed,	   0, 0, N, 0), // return number of hits collapsed into this
 T(contains,	   2, 2, N, 0), // return position of substring, or empty string
@@ -1317,6 +1319,17 @@ eval(const string &fmt, const vector<string> &param)
 		if (!value.empty()) value.erase(value.size() - 1);
 		break;
 	    }
+	    case CMD_cgiparams: {
+		const string* prev = NULL;
+		for (auto&& i : cgi_params) {
+		    if (prev && i.first == *prev) continue;
+		    value += i.first;
+		    value += '\t';
+		    prev = &i.first;
+		}
+		if (!value.empty()) value.erase(value.size() - 1);
+		break;
+	    }
 	    case CMD_chr:
 		Xapian::Unicode::append_utf8(value, string_to_int(args[0]));
 		break;
@@ -2549,9 +2562,9 @@ OmegaExpandDecider::OmegaExpandDecider(const Xapian::Database & db_,
 	    unsigned char ch = term[0];
 	    bool stemmed = (ch == 'Z');
 	    if (stemmed) {
-	       term.erase(0, 1);
-	       if (term.empty()) continue;
-	       ch = term[0];
+		term.erase(0, 1);
+		if (term.empty()) continue;
+		ch = term[0];
 	    }
 
 	    if (C_isupper(ch)) {
